@@ -7,6 +7,8 @@ decorator instead.
 import inspect
 import warnings
 
+__all__ = ["jit"]
+
 
 def ijit(first=None, *args, **kwargs):
     """Identity JIT, returns unchanged function."""
@@ -16,8 +18,8 @@ def ijit(first=None, *args, **kwargs):
 
     if inspect.isfunction(first):
         return first
-    else:
-        return _jit
+
+    return _jit
 
 
 try:
