@@ -66,6 +66,56 @@ def _change_config(tensor, metric, newconfig):
     return chain_config_change()
 
 
+def tensor_product(tensor1, tensor2, i=None, j=None):
+    """Tensor Product of ``tensor1`` and ``tensor2``
+
+    Parameters
+    ----------
+    tensor1 : ~einsteinpy.symbolic.BaseRelativityTensor
+    tensor2 : ~einsteinpy.symbolic.BaseRelativityTensor
+    i : int, optional
+        contract ``i``th index of ``tensor1``
+    j : int, optional
+        contract ``j``th index of ``tensor2``
+
+
+    Returns
+    -------
+    ~einsteinpy.symbolic.BaseRelativityTensor
+        tensor of appropriate rank
+
+    Raises
+    ------
+    ValueError
+        Raised when ``i`` and ``j`` both indicate 'u' or 'l' indices
+    """
+    product = tensorproduct(tensor1.arr, tensor2.arr)
+
+    if (i or j) is None:
+        newconfig = tensor1.config + tensor2.config
+    else:
+        if tensor1.config[i] == tensor2.config[j]:
+            raise ValueError(
+                "Index summation not allowed between %s and %s indices"
+                % (tensor1.config[i], tensor2.config[j])
+            )
+
+        product = simplify(tensorcontraction(product, (i, len(tensor1.config) + j)))
+
+        con = tensor1.config[:i] + tensor1.config[i + 1 :]
+        fig = tensor2.config[:j] + tensor2.config[j + 1 :]
+        newconfig = con + fig
+
+    return BaseRelativityTensor(
+        product,
+        syms=tensor1.syms,
+        config=newconfig,
+        parent_metric=tensor1.parent_metric,
+        variables=tensor1.variables,
+        functions=tensor1.functions,
+    )
+
+
 class Tensor:
     """
     Base Class for Tensor manipulation
@@ -252,11 +302,13 @@ class BaseRelativityTensor(Tensor):
             List of crucial symbols dentoting time-axis and/or spacial axis.
             For example, in case of 4D space-time, the arrangement would look like [t, x1, x2, x3].
         config : str
-            Configuration of contravariant and covariant indices in tensor. 'u' for upper and 'l' for lower indices. Defaults to 'll'.
+            Configuration of contravariant and covariant indices in tensor.
+            'u' for upper and 'l' for lower indices. Defaults to 'll'.
         parent_metric : ~einsteinpy.symbolic.metric.MetricTensor or None
             Metric Tensor for some particular space-time which is associated with this Tensor.
         variables : tuple or list or set
-            List of symbols used in expressing the tensor other than symbols associated with denoting the space-time axis.
+            List of symbols used in expressing the tensor,
+            other than symbols associated with denoting the space-time axis.
             Calculates in real-time if left blank.
         functions : tuple or list or set
             List of symbolic functions used in epressing the tensor.
